@@ -30,7 +30,7 @@ use File::Spec;
 sub dl_load_flags { 0x01 } # global option
 
 BEGIN {
-  $VERSION = '0.04';
+  $VERSION = '0.05';
   bootstrap Net::WDNS $VERSION;
 }
 
@@ -40,8 +40,6 @@ sub DEBUG { @_ ? $Debug = shift : $Debug }
 
 DEBUG(0);
 
-use Data::Dumper;
-
 use constant NMSG_LIB_NAME => 'nmsg';
 
 sub wdns_have_library {
@@ -217,6 +215,11 @@ our %EXPORT_TAGS = (
   const => [keys %Const],
 );
 
+require Net::WDNS::Msg;
+require Net::WDNS::Question;
+require Net::WDNS::RD;
+require Net::WDNS::RR;
+
 ###############################################################################
 
 1;
@@ -233,7 +236,7 @@ Net::WDNS - Perl extension for the wdns low-level DNS library
 
   # The primary interface to libwdns is through Net::WDNS::Msg objects:
 
-  use Net::Nmsg qw(:func);
+  use Net::WDNS qw(:func);
 
   for my $pkt (@pkt_source) {
     my $msg = parse_message($pkt); # same as Net::WDNS::Msg->new($pkt)
@@ -457,7 +460,7 @@ Return the section (0-3) of a raw msg as an array of blessed objects
 
 =head1 SEE ALSO
 
-L<Net::Nmsg>
+L<Net::WDNS::Msg>, L<Net::WDNS::Question>, L<Net::WDNS::RD>, L<Net::WDNS::RR>, L<Net::Nmsg>
 
 The wdns library can be downloaded from: https://github.com/farsightsec/wdns
 
@@ -467,7 +470,7 @@ Matthew Sisk, E<lt>sisk@cert.orgE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2014 by Carnegie Mellon University
+Copyright (C) 2015 by Carnegie Mellon University
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License, as published by
